@@ -5,7 +5,7 @@
 =head1 Name
 
  Math::Intersection::Circle::Line - Find the points at which circles and lines
- intersect and the area of these intersections.
+ intersect to test geometric intuition.
 
 =head1 Synopsis
 
@@ -13,7 +13,7 @@
  use Test::More q(no_plan);
  use utf8;
 
- # Euler Line, see: https://en.wikipedia.org/wiki/Euler_line
+ # Euler Line, see: L<https://en.wikipedia.org/wiki/Euler_line>
 
  if (1)
   {my @t = (0, 0, 4, 0, 0, 3);                                                  # Corners of the triangle
@@ -35,8 +35,12 @@
      my ($nx, $ny, $nr) = ninePointCircle {@_} $x, $y, $𝘅, $𝘆, $𝕩, $𝕪;          # Coordinates of centre and radius of nine point circle
      my ($cx, $cy)      = centroid        {@_} $x, $y, $𝘅, $𝘆, $𝕩, $𝕪;          # Coordinates of centroid
      my ($ox, $oy)      = orthoCentre     {@_} $x, $y, $𝘅, $𝘆, $𝕩, $𝕪;          # Coordinates of orthocentre
-     ok join(' ', $y, $cy, $y+$nr, $𝘆, $y+2*$nr, $oy) eq                        # Calculated points along Euler's line
-        join(' ', 100, 200, 300, 400, 500, 600);                                # The actual six equally spaced points along Euler's line
+     ok near(100, $y);                                                          # Circumcentre to base of triangle
+     ok near(200, $cy);                                                         # Circumcentre to lower circumference of nine point circle
+     ok near(300, $y+$nr);                                                      # Circumcentre to centre of nine point circle
+     ok near(400, $𝘆);                                                          # Circumcentre to apex of isosceles triangle
+     ok near(500, $y+2*$nr);                                                    # Circumcentre to upper circumference of nine point circle
+     ok near(600, $oy);                                                         # Circumcentre to orthocentre
     } 0, 0, $r,  0, $r/4, 1, $r/4;                                              # Chord at 1/4 radius
   }
 
@@ -87,12 +91,10 @@
   }
 
 =cut
-# Since 1.005
-# 2015/12/21 Zero radius circle intersects with a line if the centre is collinear with the line
 package Math::Intersection::Circle::Line;
 #-------------------------------------------------------------------------------
 # Locate the points at which lines and circles cross in two dimensions
-# Philip R Brenan at gmail dot com, Appa Apps Ltd, 2015
+# Philip R Brenan at gmail dot com, Appa Apps Ltd, 2016, http://www.appaapps.com
 #-------------------------------------------------------------------------------
 
 use v5.18;
@@ -136,6 +138,7 @@ sub near4($$$$;$$$$)
 #-------------------------------------------------------------------------------
 
 sub 𝝿 {4*atan2(1,1)}                                                            # Pi
+sub acos($) {my ($a) = @_; atan2(sqrt(1 - $a**2), $a)}                          # acos
 
 #-------------------------------------------------------------------------------
 # Length of a vector
@@ -249,7 +252,7 @@ sub intersectionCircles(&$$$$$$)
 
   my ($𝕏, $𝕐) = ($𝘅 - $x, $𝘆 - $y);                                             # Vector between centres
   my $𝗹 = vectorLength($𝕏, $𝕐);                                                 # Distance between centres
-  return &$sub("No intersection!") if $𝗹 > $r + $𝗿 or $𝗹 < abs($r - $𝗿);         # The circles are too far apart or too close to intersect
+  return &$sub("No intersection!") if $𝗹 > $r + $𝗿 or $𝗹 < abs($r - $𝗿);        # The circles are too far apart or too close to intersect
 
   my ($𝕩, $𝕪) = ($𝕏 / $𝗹, $𝕐 / $𝗹);                                             # Unit vector between centres
   my $a = ($r*$r - $𝗿*$𝗿 + $𝗹*$𝗹)/ (2*$𝗹);                                      # Length of the common side
@@ -367,7 +370,7 @@ sub intersectionLines(&$$$$$$$$)
       my $s  = $La / $Lb;                                                       # Scale factor for 𝗟𝗯
       &$sub($𝗫 + $s * ($𝗯x - $𝗫), $𝗬 + $s * ($𝗯y - $𝗬))                         # Point of intersection
      } $𝗫,$𝗬,  $𝕏,$𝕐,  $𝗮x,$𝗮y;                                                 # Find 𝗯 on second line
-   } $𝘅,$𝘆,  $𝕩,$𝕪,  $𝗫,$𝗬;                                                      # Find 𝗮 on first line
+   } $𝘅,$𝘆,  $𝕩,$𝕪,  $𝗫,$𝗬;                                                     # Find 𝗮 on first line
  }
 
 #-------------------------------------------------------------------------------
@@ -645,6 +648,22 @@ sub areaOfPolygon(&@)
   &$sub($area)                                                                  # Area of polygon
  }
 
+#-------------------------------------------------------------------------------
+# 𝗦mallest positive angle made at the intersection of two lines, expressed in degrees
+# 𝗞nown: coordinates of start and end of each line segment
+# 𝗙ind: smallest angle between the two lines or zero if they do not intersect
+# 𝗠ethod: use dot product
+#-------------------------------------------------------------------------------
+
+sub smallestPositiveAngleBetweenTwoLines($$$$$$$$)
+ {my ($x, $y, $𝘅, $𝘆, $X, $Y, $𝗫, $𝗬) = @_;                                     # Start and end coordinates of two line segments
+  my ($𝕩, $𝕪) = ($𝘅 - $x, $𝘆 - $y);                                             # Vector along first line segment
+  my ($𝕏, $𝕐) = ($𝗫 - $X, $𝗬 - $Y);                                             # Vector along second line segment
+  my $r = acos(($𝕩*$𝕏 + $𝕪*$𝕐) / sqrt(($𝕩*$𝕩+$𝕪*$𝕪) * ($𝕏*$𝕏 + $𝕐*$𝕐)));        # Result in radians
+  my $𝗿 = abs(180 * $r / 𝝿());                                                  # Result in positive degrees
+  $𝗿 > 90 ? 180 - $𝗿 : $𝗿                                                       # Smallest angle between two lines
+ }
+
 #-------------------------------------------------------------------------------
 # 𝗜s a triangle equilateral?
 # 𝗞nown: coordinates of each corner=vertex of the triangle
@@ -703,23 +722,20 @@ isEquilateralTriangle isIsoscelesTriangle isRightAngledTriangle);
 
 @EXPORT_OK = qw(midPoint near near2 near3 near4 rotate90CW rotate90CCW
 rotate90AroundMidPoint vectorLength 𝝿 lengthsOfTheSidesOfAPolygon
-threeCollinearPoints);
+threeCollinearPoints smallestPositiveAngleBetweenTwoLines);
 
 $EXPORT_TAGS{all} = [@EXPORT, @EXPORT_OK];
-#$VERSION  = '1.003'; # Sun 30 Aug 2015 - started Geometry app
-#$VERSION  = '1.005'; # Sun 20 Dec 2015 - still going!
-$VERSION   = '1.006'; # Sat 02 Jan 2016 - Euler's line divided into 6 equal pieces
 
 =head1 Description
 
- Find the points at which circles and lines intersect and the area of these
- intersections.
+ Find the points at which circles and lines intersect to test geometric
+ intuition.
 
  Fast, fun and easy to use these functions are written in 100% Pure Perl.
 
-=head2 areaOfTriangle sub triangle
+=head2 areaOfTriangle 𝘀𝘂𝗯 triangle
 
- Calls sub($a) where $a is the area of the specified triangle:
+ Calls 𝘀𝘂𝗯($a) where $a is the area of the specified triangle:
 
  A triangle is specified by supplying a list of six numbers:
 
@@ -728,21 +744,21 @@ $VERSION   = '1.006'; # Sat 02 Jan 2016 - Euler's line divided into 6 equal piec
  where (x, y), (𝘅, 𝘆) and (𝕩, 𝕪) are the coordinates of the vertices of the
  triangle.
 
-=head2 areaOfPolygon sub points...
+=head2 areaOfPolygon 𝘀𝘂𝗯 points...
 
- Calls sub($a) where $a is the area of the polygon with vertices specified by
- the point.
+ Calls 𝘀𝘂𝗯($a) where $a is the area of the polygon with vertices specified by
+ the points.
 
  A point is specified by supplying a list of two numbers:
 
   (𝘅, 𝘆)
 
-=head2 centroid sub triangle
+=head2 centroid 𝘀𝘂𝗯 triangle
 
- Calls sub($x,$y) where $x,$y are the coordinates of the centroid of the
+ Calls 𝘀𝘂𝗯($x,$y) where $x,$y are the coordinates of the centroid of the
  specified triangle:
 
- See: https://en.wikipedia.org/wiki/Centroid
+ See: L<https://en.wikipedia.org/wiki/Centroid>
 
  A triangle is specified by supplying a list of six numbers:
 
@@ -751,13 +767,13 @@ $VERSION   = '1.006'; # Sat 02 Jan 2016 - Euler's line divided into 6 equal piec
  where (x, y), (𝘅, 𝘆) and (𝕩, 𝕪) are the coordinates of the vertices of the
  triangle.
 
-=head2 circumCentre sub triangle
+=head2 circumCentre 𝘀𝘂𝗯 triangle
 
- Calls sub($x,$y,$r) where $x,$y are the coordinates of the centre of the
+ Calls 𝘀𝘂𝗯($x,$y,$r) where $x,$y are the coordinates of the centre of the
  circle drawn through the corners of the specified triangle and $r is its
  radius:
 
- See: https://en.wikipedia.org/wiki/Circumscribed_circle
+ See: L<https://en.wikipedia.org/wiki/Circumscribed_circle>
 
  A triangle is specified by supplying a list of six numbers:
 
@@ -766,12 +782,12 @@ $VERSION   = '1.006'; # Sat 02 Jan 2016 - Euler's line divided into 6 equal piec
  where (x, y), (𝘅, 𝘆) and (𝕩, 𝕪) are the coordinates of the vertices of the
  triangle.
 
-=head2 circumCircle sub triangle
+=head2 circumCircle 𝘀𝘂𝗯 triangle
 
- Calls sub($x,$y,$r) where $x,$y are the coordinates of the circum-centre of
+ Calls 𝘀𝘂𝗯($x,$y,$r) where $x,$y are the coordinates of the circumcentre of
  the specified triangle and $r is its radius:
 
- See: https://en.wikipedia.org/wiki/Circumscribed_circle
+ See: L<https://en.wikipedia.org/wiki/Circumscribed_circle>
 
  A triangle is specified by supplying a list of six numbers:
 
@@ -780,12 +796,12 @@ $VERSION   = '1.006'; # Sat 02 Jan 2016 - Euler's line divided into 6 equal piec
  where (x, y), (𝘅, 𝘆) and (𝕩, 𝕪) are the coordinates of the vertices of the
  triangle.
 
-=head2 exCircles sub triangle
+=head2 exCircles 𝘀𝘂𝗯 triangle
 
- Calls sub([$x,$y,$r]...) where $x,$y are the coordinates of the centre of each
+ Calls 𝘀𝘂𝗯([$x,$y,$r]...) where $x,$y are the coordinates of the centre of each
  ex-circle and $r its radius for the specified triangle:
 
- See: https://en.wikipedia.org/wiki/Incircle_and_excircles_of_a_triangle
+ See: L<https://en.wikipedia.org/wiki/Incircle_and_excircles_of_a_triangle>
 
  A triangle is specified by supplying a list of six numbers:
 
@@ -794,12 +810,12 @@ $VERSION   = '1.006'; # Sat 02 Jan 2016 - Euler's line divided into 6 equal piec
  where (x, y), (𝘅, 𝘆) and (𝕩, 𝕪) are the coordinates of the vertices of the
  triangle.
 
-=head2 circleInscribedInTriangle sub triangle
+=head2 circleInscribedInTriangle 𝘀𝘂𝗯 triangle
 
- Calls sub($x,$y,$r) where $x,$y are the coordinates of the centre of
+ Calls 𝘀𝘂𝗯($x,$y,$r) where $x,$y are the coordinates of the centre of
  a circle which touches each side of the triangle just once and $r is its radius:
 
- See: https://en.wikipedia.org/wiki/Incircle_and_excircles_of_a_triangle#Incircle
+ See: L<https://en.wikipedia.org/wiki/Incircle_and_excircles_of_a_triangle#Incircle>
 
  A triangle is specified by supplying a list of six numbers:
 
@@ -964,13 +980,13 @@ $VERSION   = '1.006'; # Sat 02 Jan 2016 - Euler's line divided into 6 equal piec
  where (x, y), (𝘅, 𝘆) and (𝕩, 𝕪) are the coordinates of the vertices of the
  triangle.
 
-=head2 ninePointCircle sub triangle
+=head2 ninePointCircle 𝘀𝘂𝗯 triangle
 
- Calls sub($x,$y,$r) where $x,$y are the coordinates of the centre of the
+ Calls 𝘀𝘂𝗯($x,$y,$r) where $x,$y are the coordinates of the centre of the
  circle drawn through the midpoints of each side of the specified triangle and
- $r is its radius which guves the nine point circle:
+ $r is its radius which gives the nine point circle:
 
- See: https://en.wikipedia.org/wiki/Nine-point_circle
+ See: L<https://en.wikipedia.org/wiki/Nine-point_circle>
 
  A triangle is specified by supplying a list of six numbers:
 
@@ -979,12 +995,12 @@ $VERSION   = '1.006'; # Sat 02 Jan 2016 - Euler's line divided into 6 equal piec
  where (x, y), (𝘅, 𝘆) and (𝕩, 𝕪) are the coordinates of the vertices of the
  triangle.
 
-=head2 orthoCentre sub triangle
+=head2 orthoCentre 𝘀𝘂𝗯 triangle
 
- Calls sub($x,$y) where $x,$y are the coordinates of the ortho-centre of the
+ Calls 𝘀𝘂𝗯($x,$y) where $x,$y are the coordinates of the orthocentre of the
  specified triangle:
 
- See: https://en.wikipedia.org/wiki/Altitude_%28triangle%29
+ See: L<https://en.wikipedia.org/wiki/Altitude_%28triangle%29>
 
  A triangle is specified by supplying a list of six numbers:
 
@@ -999,7 +1015,7 @@ $VERSION   = '1.006'; # Sat 02 Jan 2016 - Euler's line divided into 6 equal piec
  necessary to make the plane discrete by merging points closer than the
  distance contained in this variable, which is set by default to 1e-6.
 
-=head1 Export
+=head1 Exports
 
  The following functions are exported by default:
 
@@ -1050,6 +1066,8 @@ $VERSION   = '1.006'; # Sat 02 Jan 2016 - Euler's line divided into 6 equal piec
 
 =over
 
+=item C<acos()>
+
 =item C<lengthsOfTheSidesOfAPolygon()>
 
 =item C<midPoint()>
@@ -1070,6 +1088,8 @@ $VERSION   = '1.006'; # Sat 02 Jan 2016 - Euler's line divided into 6 equal piec
 
 =item C<rotate90AroundMidPoint()>
 
+=item C<smallestPositiveAngleBetweenTwoLines()>
+
 =item C<threeCollinearPoints()>
 
 =item C<vectorLength()>
@@ -1078,6 +1098,19 @@ $VERSION   = '1.006'; # Sat 02 Jan 2016 - Euler's line divided into 6 equal piec
 
 =back
 
+=head1 Changes
+
+ 1.003 Sun 30 Aug 2015 - Started Geometry app
+ 1.005 Sun 20 Dec 2015 - Still going!
+ 1.006 Sat 02 Jan 2016 - Euler's line divided into 6 equal pieces
+ 1.007 Sat 02 Jan 2016 - [rt.cpan.org #110849] Test suite fails with uselongdouble
+
+=cut
+
+$VERSION   = '1.007';
+
+=pod
+
 =head1 Installation
 
  Standard Module::Build process for building and installing modules:
@@ -1103,7 +1136,7 @@ $VERSION   = '1.006'; # Sat 02 Jan 2016 - Euler's line divided into 6 equal piec
 
 =head1 Copyright
 
- Copyright (c) 2015 Philip R Brenan.
+ Copyright (c) 2016 Philip R Brenan.
 
  This module is free software. It may be used, redistributed and/or
  modified under the same terms as Perl itself.
